package test.matchers;

import java.util.List;
import java.util.HashMap;
import java.util.Iterator;
import java.util.ArrayList;

import junit.framework.TestCase;
import junit.framework.Test;
import junit.framework.TestSuite;

import javax.provisioning.matcher.*;

public class DimensionMatcherTest extends TestCase {

    private List dimensionMatchers;

    public DimensionMatcherTest(String name) {
        super(name);
    }

    public void testDimensionMatcher() {
        Iterator i = dimensionMatchers.iterator();
        while (i.hasNext()) {
            DimensionMatcher matcher = (DimensionMatcher) i.next();
            testMatchValues(matcher);
        }
    }

    public void setUp() {
        DimensionMatcher ttt = new DimensionMatcher();
        DimensionMatcher ttf = new DimensionMatcher();
        DimensionMatcher tft = new DimensionMatcher();
        DimensionMatcher tff = new DimensionMatcher();
        DimensionMatcher ftt = new DimensionMatcher();
        DimensionMatcher ftf = new DimensionMatcher();
        DimensionMatcher fft = new DimensionMatcher();
        DimensionMatcher fff = new DimensionMatcher();

        try {
            ttt.init("TTT", getParamMap("true", "true", "true"));
            ttf.init("TTF", getParamMap("true", "true", "false"));
            tft.init("TFT", getParamMap("true", "false", "true"));
            tff.init("TFF", getParamMap("true", "false", "false"));
            ftt.init("FTT", getParamMap("false", "true", "true"));
            ftf.init("FTF", getParamMap("false", "true", "false"));
            fft.init("FFT", getParamMap("false", "false", "true"));
            fff.init("FFF", getParamMap("false", "false", "false"));
        } catch (MatcherException e) {
            e.printStackTrace();
        }

        dimensionMatchers = new ArrayList();

        dimensionMatchers.add(ttt);
        dimensionMatchers.add(ttf);
        dimensionMatchers.add(tft);
        dimensionMatchers.add(tff);
        dimensionMatchers.add(ftt);
        dimensionMatchers.add(ftf);
        dimensionMatchers.add(fft);
        dimensionMatchers.add(fff);
    }

    private HashMap getParamMap(String allMustMatch, String caseInsensitive, String wildCardsOn) {
        HashMap initParams = new HashMap();
        initParams.put("allMustMatch", allMustMatch);
        initParams.put("caseInsensitive", caseInsensitive);
        initParams.put("wildCardsOn", wildCardsOn);
        return initParams;
    }

    private float matchValue(String requirement, String capability, DimensionMatcher matcher) {
        List capabilities = new ArrayList();
        capabilities.add(capability);

        List requirements = new ArrayList();
        requirements.add(requirement);

        try {
            float f = matcher.match(requirements, capabilities);
            return f;
        } catch (MatcherException e) {
            e.printStackTrace();
        }
        return -1f;
    }

    private void testMatchValues(DimensionMatcher matcher) {

        float f = matchValue("96+ x 128+", "96+ x 128+", matcher);
        assertTrue("Same Dimension: Plus", f == 1f);

        f = matchValue("96+x128+", "96+ x 128+", matcher);
        assertTrue("Same Dimension: Plus", f == 1f);

        f = matchValue("96 x 128", "96 x 128", matcher);
        assertTrue("Same Dimension: Exact", f == 1f);

        f = matchValue("96+ x 128+", "100 x 128+", matcher);
        assertTrue("Capability Width Higher: No Capability Plus Sign", f == .98f);

        f = matchValue("96 x 128+", "100 x 128+", matcher);
        assertTrue("Capability Width Higher: No Plus Signs", f == 0f);

        f = matchValue("96 x 128+", "90 x 128+", matcher);
        assertTrue("Capability Width Lower: No Plus Signs", f == 0f);

        f = matchValue("106+ x 128+", "96+ x 128+", matcher);
        assertTrue("Requirement Width Higher", f == 0f);

        f = matchValue("86+ x 128+", "96+ x 128+", matcher);
        assertTrue("Requirement Width Lower", f == .9479166f);

        f = matchValue("96+ x 128+", "96+ x 108+", matcher);
        assertTrue("Capability Height Lower", f == 0f);

        f = matchValue("96+ x 128+", "92+ x 108+", matcher);
        assertTrue("Capability Dimension Lower", f == 0f);

        f = matchValue(null, null, matcher);
        assertTrue("Both Null", f == 1f);

        f = matchValue("-96+ x 128+", "42+ x 108+", matcher);
        assertTrue("Negative Requirement", f == 0f);

        f = matchValue("96+ x 128+", "-42 x 108+", matcher);
        assertTrue("Negative Capability", f == 0f);

        f = matchValue("96+ 128+", "-42 x 108+", matcher);
        assertTrue("No x Sign", f == 0f);

        f = matchValue("fdsf", "42+ x 108+", matcher);
        assertTrue("No Integer Value", f == 0f);

        f = matchValue("89a+ x 68dsaf+", "-42 x 108+", matcher);
        assertTrue("Garbage", f == 0f);

    }
}
