/*
 *  JVending
 *  Copyright (C) 2004  Shane Isbell
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.jvending.provisioning.deliverable;

import java.util.List;
import java.util.Properties;
import java.util.Enumeration;
import java.util.logging.*;

import java.io.InputStream;
import java.io.OutputStream;
import java.io.IOException;
import java.io.ByteArrayOutputStream;
import java.io.ByteArrayInputStream;

import java.net.URI;
import java.net.URL;

/**
 *
 * @author Shane Isbell
 * @version 1.0
 */

public final class JadDescriptorFile extends BaseDescriptorFile {

    private static Logger logger = Logger.getLogger("JadDescriptorFile");

    private Properties jadProp;

    private final URL url;

    private final String mimeType;

    public JadDescriptorFile(URL url, URI uri, String mimeType, List contentFiles) {
        super(url, uri, mimeType, contentFiles);
        this.url = url;
        this.mimeType = mimeType;
    }

    public String getAppProperty(String name) {
        if(jadProp == null) loadProperties();
        return (String) jadProp.getProperty(name);
    }

    public void setAppProperty(String name, String value) {
        if(jadProp == null) loadProperties();
        jadProp.setProperty(name, value);
    }

    //class that invokes method is responsible for closing connection
    public void writeContents(OutputStream os) throws IOException {
        if(jadProp == null) loadProperties();
        
        for(Enumeration enum = jadProp.propertyNames(); enum.hasMoreElements(); ) {
            String key = (String) enum.nextElement();
            String value = (String) jadProp.getProperty(key);
            if(key != null && value != null) os.write((key + ": " + value + "\r\n").getBytes());
        }
    }

    public InputStream getInputStream() throws IOException {
        if(url == null) throw new IOException("URL Value is Null");   
        if(jadProp == null) loadProperties();

        ByteArrayOutputStream os  = new ByteArrayOutputStream();
        try {
            writeContents(os);
        } catch(IOException e) {
            throw new IOException("Could not get InputStream.");
        } finally {
            try {
                os.close();
            } catch(IOException e) {
                logger.info("Could not close connection.");
            }
        }
        return (InputStream) new ByteArrayInputStream(os.toByteArray());
    }

    private void loadProperties() {
        InputStream is = null;
        try {
            is = getURL().openStream();
            if(is == null) throw new IOException("URL Value is Null");
            jadProp = new Properties();
            jadProp.load(is);
        } catch (IOException e) {
            logger.log(Level.INFO, "Could not load properties: URL = " + url + 
                       ", Mime-Type = " + mimeType, e);
        } finally {
            try {
                if(is != null) is.close();
            } catch(IOException e) {
                logger.info("Could not close connection.");
            }
        }
    }
}