package org.jvending.provisioning.impl;

import org.jvending.registry.hibernate.HibernateDAORegistry;
import org.jvending.provisioning.dao.ContentAccessorDAO;

import java.io.IOException;
import java.io.OutputStream;

import java.util.logging.*;

import javax.servlet.ServletException;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * This class is responsible for grabbing content from a data source.
 * @author Shane Isbell
 * @since 2.0.0
 */

public final class ContentAccessorServlet extends HttpServlet {

    private static Logger logger = Logger.getLogger("ContentAccessorServlet");

    public void service(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {

        HibernateDAORegistry hibernateRegistry = (HibernateDAORegistry)
                this.getServletContext().getAttribute("org.jvending.registry.hibernate.HibernateDAORegistry");

        String bundleId = request.getParameter("id");
        String type = request.getParameter("type");
        String fileName = request.getParameter("fileName");
        logger.info("Making content accessor request: ID = " + bundleId +
                      ", Type = " + type);

        OutputStream os = null;

        ContentAccessorDAO contentDAO = (ContentAccessorDAO) hibernateRegistry.find("dao:content-accessor");
        if(contentDAO == null) {
            logger.severe("JV-Could not locate the ContentAccessorDAO");
        }
        byte[] content = null;
        try {
            if(type.equals("descriptor")) {
                logger.finest("Getting descriptor from data source: Bundle Id = " +
                               bundleId);
                content = contentDAO.getDescriptorFor(bundleId);
            } else if(type.equals("content")) {
                logger.finest("Getting content from data source: Bundle Id = " +
                               bundleId);
                content = contentDAO.getContentFor(bundleId);
            } else if(type.equals("icon")) {
                logger.finest("Getting icon from data source: Bundle Id = " + bundleId);
                content = contentDAO.getIconFor(bundleId, fileName);
            } else if(type.equals("preview")) {
                logger.finest("Getting preview from data source: Bundle Id = " + bundleId +
                              ", File Name = " + fileName);
                content = contentDAO.getPreviewFor(bundleId, fileName);
            } else if(type.equals("descriptorContent")) {
                logger.finest("Getting descriptor content from data source: Bundle Id = " + bundleId +
                              ", File Name = " + fileName);
                content = contentDAO.getDescriptorContentFor(bundleId, fileName);
            }
            if(content == null) {
                logger.info("Could not obtain requested content: Id = " + bundleId +
                            ", type = " + type + ", File Name = " + fileName);
                return;
            }

            os = (OutputStream) response.getOutputStream();
            os.write(content);
        } catch(IOException e) {
            e.printStackTrace();
        } finally {
            try {
                if(os != null) os.close();
            } catch(IOException e) {
                e.printStackTrace();
            }
        }
    }
}