package org.jvending.provisioning.impl;

import junit.framework.TestCase;
import org.jvending.registry.RepositoryRegistry;
import org.jvending.provisioning.stocking.StockingContext;
import org.jvending.provisioning.stocking.StockingPolicy;
import org.jvending.provisioning.stocking.StockingException;
import org.jvending.provisioning.stocking.handler.StockingHandler;
import org.jvending.provisioning.stocking.handler.StockingHandlerConfig;
import org.jvending.provisioning.config.StockingHandlersRepository;
import org.easymock.MockControl;

import javax.servlet.ServletContext;
import java.io.IOException;

public class StockingContextImplTest extends TestCase {

    private static String baseDir = System.getProperty("basedir");

    private StockingContext stockingContext;

    public void setUp() {
        RepositoryRegistry repositoryRegistry = RepositoryRegistry.Factory.create();
        try {
            repositoryRegistry.loadFromFile(baseDir + "/src/test/resources/registry-config.xml");
        } catch (IOException e) {
            e.printStackTrace();
            fail("Could not load the registry-config file");
        }

        MockControl controlServletContext = MockControl.createNiceControl(ServletContext.class);
        ServletContext servletContext = (ServletContext) controlServletContext.getMock();

        servletContext.getAttribute("org.jvending.registry.RepositoryRegistry");
        controlServletContext.setReturnValue(repositoryRegistry);

        controlServletContext.replay();

        stockingContext = new StockingContextImpl();
        stockingContext.init(servletContext);
    }

    public void testStockingHandlerConfig() {
        StockingHandler stockingHandler = null;
        try {
            stockingHandler = stockingContext.getStockingHandler("GENERIC");
        } catch (StockingException e) {
            e.printStackTrace();
            fail("Could not obtain StockingHandler");
        }
        assertNotNull("StockingHandler is null: Name = GENERIC", stockingHandler);
        StockingHandlerConfig config = stockingHandler.getStockingHandlerConfig();
        StockingPolicy policy = config.getContentPolicy();
        assertEquals("Incorrect value for the fetch content parameter", true, policy.hasFetchContent());
        policy = config.getIconPolicy();
        assertEquals("Incorrect value for the fetch content parameter", false, policy.hasFetchContent());
    }

    public void testNullNameForStockingHandler() {
        try {
            StockingHandler stockingHandler = stockingContext.getStockingHandler(null);
            fail("Obtained a StockingHandler for when the name is null");
        } catch (StockingException e) { }
    }

    public void testBogusNameForStockingHandler() {
        StockingHandler stockingHandler = null;
        try {
            stockingHandler = stockingContext.getStockingHandler("BoGus");
            fail("Should have thrown a StockingException for a non-existent StockingHandler");
        } catch (StockingException e) { }
        assertNull("StockingHandler should be null.", stockingHandler);
    }
}
